/** @jsxImportSource @emotion/react */
import * as React from "react";
/**编辑器每一行的拼装：列式布局: column = 最少1 -- 最多是 5 列的。
 布局子孙都是平等的，宽度都平均分配，预期高度在同一行排列也是均衡整齐或高度一致的，
 父窗口宽度不确定的， 具体显示几个列是自适应的，最多列数固定。
 列数动态确定， 之后的子孙实际宽度都是铺满的100%。
 不使用滚动条的，大尺寸元素上 都没有固定数值的px;
 子孙的宽度没有固定px的，布局组件的子孙都是可在宽度上做自适应的。只有目标多少列排列是敲定固定的，也就是预期最大父窗口宽度场合可以安排最多几个列的元素。
 宽度上 竟然小到了1列都放不下了， fitable=true传递给子孙；
 子孙输入Line组件的断线折腰宽度在布局组件上就的设置switchPx参数。
 布局组件来传递进来布局紧凑与否参数fitable。也就是遇到最小最小的父窗口宽度情形，在只安排单列元素场合下的，给输入Line组件紧凑提示。
 最后一行：非满格的 落单子孙个数， 居中？，宽度协调一致。
 最多列数是应用场景 程序敲定， 大概会放得下几个列啊{已经考虑了需求上级大的布局切换需求后，反正就是最大可能性几个列}。
 【特点】对比css自带的原生的grid 、列式 、flexBox等布局模式会更加的适合 自适应，没有生硬缺点，灵活性好，还得支持打印时没毛病。
 */
interface LineColumnProps extends React.HTMLAttributes<HTMLDivElement> {
    /** 默认布局断点数的 列数安排： must >=1 and <=8 但是若定义breaks不限制的；
     * 设置了column就不需要配置breaks；但是column比breaks优先级底。两个都配的否则优先看的。
     *  */
    column?: number;
    /**自定义； 优先级更高的。设置了breaks就不需要配置column；
     * */
    breaks?: number[];
    /** The contents of the layer */
    children: React.ReactNode;
    /**LineColumn自己在屏幕的宽度占比百分比。很多容器不是浏览器Tab/Viewpoint的宽度100%的。
     * 如果percent没有配置的，会启动默认机制：也就是接受useContext(PanelEnlargeCtx)的安排假设取值：
     * 【限制】点击打印预览打印的切换时，percent不要变动，可打印页数在预览render之前就被限定敲定了。所以会有问题的。
     * percent===0就不显示的。
     * */
    percent?: number;
    /**不采信外部直接控制的，没有配置percent的情形：约定的框架页面位置关系。
     * 在左半边的框架页面之内的，而非右边的半边页面内的
     * 启用useContext(PanelEnlargeCtx)+useMMenuBarOcup+inLeft的设置，
     * 若设置inLeft就不要再设置percent，后者参数percent的优先级更高的！
     * */
    inLeft?: boolean;
}
/**【3种思路】如何避免依据屏幕宽度做动态布局的效果，在遇到打印切换时刻，打印预览太草率地限定了纸张页数所导致的问题。
 * 1：每个LineColumn出现地方都应该配置打印A4。A4横板的。A3?几个常见打印目的地纸张的正常应该的效果：也就是suitableCls大小{a4:,a4L:,a3,}。
 * 2：直接约束准备打印浏览器的窗口宽度做法。
 * 3：完整的用css来调整的？【确保打印的正确性需要】只用css，不用JS做动态内容？测量div宽度做自适应的危险；
 * 重新加载？打印敲定页数之后才会再一次render的。根本没机会计算ref.div最新宽度甚至用beforePrintHandler来setSuitableCls也没有机会提前调整。
 * printComp[]；
 * 手机上chrome打印可能有些问题；
 * 若使用固定大小列style={{columnWidth: '270px', columnGap: '20px'}}布局，大小屏幕宽度缩放适应性不好，水平方向没法对齐，感觉凌乱！。
 * 若采用style={{display: 'grid', gridTemplateColumns: 'auto auto auto'}}，也有问题：列数量不能固定啊。
 * 1：2 1：1 框架调整，右边还是左边的半边框，默认编辑区底下空间100%，屏幕媒体宽度。应该部署有几个列的？？
 * */
export declare const LineColumn: React.FunctionComponent<LineColumnProps>;
export {};
/**被动态网页的打印给折腾的：
 重新加载？打印敲定页数之后才会再一次render的。根本没机会计算ref.div最新宽度甚至用beforePrintHandler来setSuitableCls也没有机会提前调整。
 beforePrintHandler --》unmount this?重新加载
 react-to-print只会复制旧的组件页面也不能重新render的是甚至usemedia都无感知到打印。；
 【确保打印的正确性需要】只用css，不用JS做动态内容？测量div宽度做自适应的就会危险了；
 function validChildrenCount(children: any) {
     return React.Children.toArray(children).filter(child =>
         React.isValidElement(child)
     ).length;
 }
* */
